Your message dated Mon, 16 May 2022 20:35:38 +0000
with message-id <[email protected]>
and subject line Bug#1007932: fixed in cfitsio 4.1.0-1
has caused the Debian Bug report #1007932,
regarding cfitsio: gdal FTBFS on hurd-i386 due to missing support for GNU/Hurd
in cfitsio/fitsio.h
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
1007932: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1007932
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Source: cfitsio
Version: 4.0.0-1
Severity: important
Tags: patch
User: [email protected]
Usertags: hurd
Hi,
gdal (3.4.1+dfsg-1, etc) FTBFS on hurd-i386 due to missing support for
GNU/Hurd in cfitsio (4.0.0-1).
Attached is an updated patch of 03-off_t.diff, modifying fitsio.h to
achieve a successful build of gdal with the updated libcfitsio9 and
libcfitsio-dev packages.
Thanks!
Index: cfitsio-4.0.0/fitsio.h
===================================================================
--- cfitsio-4.0.0.orig/fitsio.h
+++ cfitsio-4.0.0/fitsio.h
@@ -70,7 +70,7 @@ SERVICES PROVIDED HEREUNDER."
# define _MIPS_SZLONG 64
#endif
-#if defined(linux) || defined(__APPLE__) || defined(__sgi)
+#if defined(__linux__) || defined(__APPLE__) || defined(__sgi) || defined(__GNU__)
# include <sys/types.h> /* apparently needed on debian linux systems */
#endif /* to define off_t */
@@ -84,10 +84,11 @@ SERVICES PROVIDED HEREUNDER."
/* on whether _LARGEFILE_SOURCE is defined in sys/feature_tests.h */
/* (at least on Solaris platforms using cc) */
/* Debian systems require: "(defined(linux) && defined(__off_t_defined))" */
/* the mingw-w64 compiler requires: "(defined(__MINGW32__) && defined(_OFF_T_DEFINED))" */
#if defined(_OFF_T) \
- || (defined(linux) && defined(__off_t_defined)) \
+ || (defined(__linux__) && defined(__off_t_defined)) \
+ || (defined(__GNU__) && defined(__off_t_defined)) \
|| (defined(__MINGW32__) && defined(_OFF_T_DEFINED)) \
|| defined(_MIPS_SZLONG) || defined(__APPLE__) || defined(_AIX)
# define OFF_T off_t
--- End Message ---
--- Begin Message ---
Source: cfitsio
Source-Version: 4.1.0-1
Done: Aurelien Jarno <[email protected]>
We believe that the bug you reported is fixed in the latest version of
cfitsio, which is due to be installed in the Debian FTP archive.
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Aurelien Jarno <[email protected]> (supplier of updated cfitsio package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512
Format: 1.8
Date: Mon, 16 May 2022 22:18:00 +0200
Source: cfitsio
Architecture: source
Version: 4.1.0-1
Distribution: unstable
Urgency: medium
Maintainer: Debian Astronomy Maintainers
<[email protected]>
Changed-By: Aurelien Jarno <[email protected]>
Closes: 1007932
Changes:
cfitsio (4.1.0-1) unstable; urgency=medium
.
* New upstream version:
- Refresh debian/patches/10-latex.diff.
* Fix debian/watch file to work with the new versioning scheme.
* Update 03-off_t.diff to add Hurd support. Closes: #1007932.
* Bump Standards-Version to 4.6.1 (no changes).
Checksums-Sha1:
3e0a42ab36a03cf2c9c9453a8a58ea3be1116156 2341 cfitsio_4.1.0-1.dsc
3c63ceccc4de3495b22d5a92e849d2ce027d07a6 4305184 cfitsio_4.1.0.orig.tar.gz
832c09d8f87dfcf0ec3191bc4ef7d7673de56a88 21236 cfitsio_4.1.0-1.debian.tar.xz
06c95ec625ffc5bffabd3bc8ee964d71a7147e29 5577 cfitsio_4.1.0-1_source.buildinfo
Checksums-Sha256:
dde2cfaecd960c396eaaf14c2ef0b27f370a1c159eabbf9d7ccacf997e881bef 2341
cfitsio_4.1.0-1.dsc
b367c695d2831958e7166921c3b356d5dfa51b1ecee505b97416ba39d1b6c17a 4305184
cfitsio_4.1.0.orig.tar.gz
86cea7fca2c7186e482988ffbdcc75badf9e314edb6e101ac28cb68dfb668beb 21236
cfitsio_4.1.0-1.debian.tar.xz
649c3b9f5749c2fafc0f1b78e393fd6006b6eacb9839beabb7ebb2842c245993 5577
cfitsio_4.1.0-1_source.buildinfo
Files:
ec7e69b690ededda2a9ef8ea959afe58 2341 devel optional cfitsio_4.1.0-1.dsc
4d43a98620a83549234935b6abe2e081 4305184 devel optional
cfitsio_4.1.0.orig.tar.gz
96130733fd207ca1607447ea1758e551 21236 devel optional
cfitsio_4.1.0-1.debian.tar.xz
9ddbd40d759aaaeea4716eb67552be05 5577 devel optional
cfitsio_4.1.0-1_source.buildinfo
-----BEGIN PGP SIGNATURE-----
iQIzBAEBCgAdFiEEUryGlb40+QrX1Ay4E4jA+JnoM2sFAmKCsm4ACgkQE4jA+Jno
M2t+Bg//eX6F6kv30S05aR2xjLR1IOIR+yYNjwIDZJHkpCrgfurzSuRmtrzwBV5m
Yp0jQHNKDcb6KSzSFSs0CfyvZ6ocicH//abrc85Iq0r8jeW2p2eFtVTj2dta3rWh
SzxR+AybrF237rxdKupDGXquC55Os7WEhsKyULdcjKUcmQ29RIGwCVoBn43oRVEf
WApQemul/CKO6dTXlqLMrtao7MQ4it3cL+rlQRD6RuriF0Gx14lopT5fhCrqxwJS
lGZ9YHoN6HNnIvzxq6591Dqu+1PY9oR5slemVPpaX+Ex2Os+7phN4lodySNRWSIB
+zmFCiqiegnb4NL+4WHFxUjlHyim5ht8lmxHATQATHGfEXyHnEfNShEQdqTQNqBc
oNGn1pk0n34Ck476vRSRusNiy9YK6RqdC5O5YOKGxjckvZD7tAT82UL974nsgx65
57bUBD0Ea3vzrZytYe8Kd7cnqf7GaiTXOouK4bRBHGjgF13oBCuFkVYnL9eGVMdz
0SUdJhocq0/iMZeeHl/MCdr25WRhyu4/cG+qLxwDVQweWQnQ9y/uBzeCnpWhUCyw
SVzLVEoUNZS1U7Wsmaoj5byLHDJKL4ddZzpxKHjLlCgCsHsRX/toGevKfYibZwDU
bmi3BEZcpNmP4L+0Av4NEOZuBPgqwGYK7DtB/1FIcKyXqQQPRMY=
=llsq
-----END PGP SIGNATURE-----
--- End Message ---
@@ -84,10 +84,11 @@ SERVICES PROVIDED HEREUNDER."
/* on whether _LARGEFILE_SOURCE is defined in sys/feature_tests.h */
/* (at least on Solaris platforms using cc) */
-/* Debian systems require: "(defined(linux) && defined(__off_t_defined))" */
+/* Debian systems require: "(defined(__linux__) && defined(__off_t_defined))" */
/* the mingw-w64 compiler requires: "(defined(__MINGW32__) && defined(_OFF_T_DEFINED))" */
#if defined(_OFF_T) \